=================
Bottle Utils I18n
=================

Bottle Utils is a collection of loosely related packages for developing web
applications using Bottle_ web framework. This package contains translations
utiltiies.

.. _Bottle: http://bottlepy.org/

